aboutsummaryrefslogtreecommitdiffstats
path: root/fg21sim/extragalactic/clusters/formation.py
diff options
context:
space:
mode:
Diffstat (limited to 'fg21sim/extragalactic/clusters/formation.py')
-rw-r--r--fg21sim/extragalactic/clusters/formation.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/fg21sim/extragalactic/clusters/formation.py b/fg21sim/extragalactic/clusters/formation.py
index 3bb44a9..a036069 100644
--- a/fg21sim/extragalactic/clusters/formation.py
+++ b/fg21sim/extragalactic/clusters/formation.py
@@ -63,9 +63,9 @@ class ClusterFormation:
----------
mtree : `~MergerTree`
Merging history of this cluster.
last_major_merger : dict, or None
An dictionary containing the properties of the found last/recent
major merger event, or None if not found.
"""
def __init__(self, M0, z0, zmax=3.0, ratio_major=3.0,
merger_mass_min=1e12):
@@ -203,9 +203,9 @@ class ClusterFormation:
return self.mtree
@property
- def last_major_merger(self):
+ def recent_major_merger(self):
"""
Identify and return the last major merger event
Returns
-------
@@ -63,9 +63,9 @@ class ClusterFormation:
mtree : `~MergerTree`
Merging history of this cluster.
- last_major_merger : dict, or None
- An dictionary containing the properties of the found last/recent
- major merger event, or None if not found.
+ recent_major_merger : dict, or None
+ An dictionary containing the properties of the found most recent
+ major merger event, or ``None`` if not found.
"""
def __init__(self, M0, z0, zmax=3.0, ratio_major=3.0,
@@ -203,9 +203,9 @@ class ClusterFormation:
"""
- Identify and return the last major merger event
+ Identify and return the most recent major merger event.
Returns